==> Paws-0.28.tar.gz: Paws-0.28/lib/Paws/Config/DeleteConfigurationRecorder.pm <==

package Paws::Config::DeleteConfigurationRecorder;
  use Moose;
  has ConfigurationRecorderName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteConfigurationRecorder');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Config::DeleteConfigurationRecorder - Arguments for method DeleteConfigurationRecorder on Paws::Config

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteConfigurationRecorder on the 
AWS Config service. Use the attributes of this class
as arguments to method DeleteConfigurationRecorder.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteConfigurationRecorder.

As an example:

  $service_obj->DeleteConfigurationRecorder(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> ConfigurationRecorderName => Str

The name of the configuration recorder to be deleted. You can retrieve
the name of your configuration recorder by using the
C<DescribeConfigurationRecorders> action.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteConfigurationRecorder in L<Paws::Config>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/Config/DeleteConfigurationRecorder.pm <==

package Paws::Config::DeleteConfigurationRecorder;
  use Moose;
  has ConfigurationRecorderName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteConfigurationRecorder');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Config::DeleteConfigurationRecorder - Arguments for method DeleteConfigurationRecorder on Paws::Config

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteConfigurationRecorder on the 
AWS Config service. Use the attributes of this class
as arguments to method DeleteConfigurationRecorder.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteConfigurationRecorder.

As an example:

  $service_obj->DeleteConfigurationRecorder(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> ConfigurationRecorderName => Str

The name of the configuration recorder to be deleted. You can retrieve
the name of your configuration recorder by using the
C<DescribeConfigurationRecorders> action.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteConfigurationRecorder in L<Paws::Config>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
